@@ -9,12 +9,13 @@ from django.utils import timezone
 from django.views import View
 from spid_cie_oidc.entity.jwtse import (
     create_jws,
-    encrypt_dict,
+    create_jwe,
     unpad_jwt_payload
 )
 from spid_cie_oidc.entity.models import (
     TrustChain
 )
+from spid_cie_oidc.entity.utils import get_jwks
 from spid_cie_oidc.provider.models import IssuedToken
 
 from . import OpBase
@@ -81,10 +82,16 @@ class UserInfoEndpoint(OpBase, View):
         ):
             if claim in token.session.user.attributes:
                 jwt[claim] = token.session.user.attributes[claim]
-        
+
         # sign the data
         jws = create_jws(jwt, issuer.jwks_core[0])
 
         # encrypt the data
-        jwe = encrypt_dict(jws, rp_tc.metadata['openid_relying_party']["jwks"]["keys"][0])
+        jwe = create_jwe(
+            jws,
+            get_jwks(
+                rp_tc.metadata['openid_relying_party'],
+                federation_jwks = rp_tc.jwks
+            )[0]
+        )
         return HttpResponse(jwe, content_type="application/jose")
